
#########################
Available data structures
#########################

.. automodule:: pyannote.core.segment

.. automodule:: pyannote.core.timeline

.. automodule:: pyannote.core.annotation

.. automodule:: pyannote.core.feature
